# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tools_item_json_schema_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema = typing.Union[
    typing.Optional[typing.Any],
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem]],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_message_ids_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds = typing.Union[
    typing.List[str],
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem(UncheckedBaseModel):
    id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId] = None
    name: str
    description: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription] = None
    embedding_config: TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig
    organization_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId] = (
        None
    )
    metadata: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata] = None
    created_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById] = None
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tools_item_name_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem]],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tools_item_source_type_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem]],
]
